@@ -35,7 +35,7 @@ def getCutImages(images, limit=9):
 	result = []
 	prefix = 'tmp_image/'
 	for image in images:
-		fn = prefix + os.path.basename(image)
+		fn = prefix + os.path.basename(image.replace('=', '.'))
 		with open(fn, 'wb') as f:
 			f.write(cached_url.get(image, force_cache=True, mode='b'))
 		cuts = list(cut(fn))
@@ -48,7 +48,7 @@ def getCutImages(images, limit=9):
 	return result
 
 def goodSize(w, h):
-	return h < 2 * w
+	return h < 2.1 * w
 
 def computeSize(h, p):
 	raw_h = h / (p - MARGIN * (p - 1))
